
import { Link, useNavigate } from 'react-router-dom';
import { RippleButton } from '@/components/ui/ripple-button';
import '@/styles/animations/water/index.css';
import { useAuth } from '@/hooks/use-auth';

const Hero = () => {
  const { user, hasRequiredTier } = useAuth();
  const navigate = useNavigate();
  const hasListedAccess = user && hasRequiredTier(['Listed', 'Core', 'Coach']);
  
  return (
    <section className="relative bg-gradient-to-b from-cyan-50 to-white pt-20 pb-20 px-4">
      <div className="absolute inset-0 overflow-hidden pointer-events-none">
        <div className="absolute w-96 h-96 bg-cyan-100/20 rounded-full blur-3xl -top-20 -right-20"></div>
        <div className="absolute w-96 h-96 bg-cyan-100/20 rounded-full blur-3xl -bottom-20 -left-20"></div>
      </div>
      
      <div className="mx-auto text-center max-w-4xl relative z-10">
        <h1 className="font-cy text-3xl md:text-5xl font-extrabold mb-12 bg-gradient-to-r from-cyan-600 via-teal-500 to-green-400 bg-clip-text text-transparent">
          <span>Expand Your Horizons with Ecopisteme</span>
        </h1>
        
        <div className="mb-12 max-w-2xl mx-auto space-y-8">
          <div className="text-lg md:text-xl font-cy font-bold text-cyan-800">
            <p className="mb-1 hero-quote-underline">Die Grenzen meiner Sprache bedeuten die Grenzen meiner Welt</p>
            <p className="text-cyan-600 mt-1 hero-quote-underline">– Ludwig Wittgenstein</p>
          </div>
          
          <div className="water-glass-card p-6 rounded-xl backdrop-blur-md 
                        bg-gradient-to-br from-cyan-400/5 via-teal-300/10 to-cyan-200/5
                        border border-white/20 shadow-xl">
            <div className="text-lg md:text-xl font-cy font-extrabold text-cyan-800 relative z-10">
              <p className="mb-1 hero-quote-underline">我語言的邊界，就是我世界的邊界</p>
              <div className="text-cyan-600 mt-1">
                <p className="hero-quote-underline block font-extrabold">維根斯坦</p>
              </div>
            </div>
            
            <div className="absolute inset-0 bg-gradient-to-br from-cyan-100/20 via-teal-50/10 to-transparent animate-pulse opacity-15"></div>
            <div className="absolute top-0 left-0 right-0 h-1/2 bg-gradient-to-b from-white/30 to-transparent"></div>
            
            <div className="absolute inset-0 overflow-hidden rounded-xl">
              <div className="absolute inset-0 bg-gradient-to-r from-cyan-200/10 to-teal-200/10 animate-[water-ripple_4s_infinite_ease-in-out] opacity-40"></div>
              <div className="absolute inset-0 bg-gradient-to-l from-cyan-200/10 to-teal-200/10 animate-[water-ripple_5s_infinite_ease-in-out_1s] opacity-30"></div>
            </div>
          </div>
        </div>
        
        <div className="flex flex-col md:flex-row justify-center gap-5 mt-12">
          {hasListedAccess && (
            <Link to="/listed-page">
              <RippleButton 
                variant="outline" 
                className="border-2 border-indigo-500 bg-indigo-50/20 hover:bg-indigo-100/30 text-indigo-700 px-8 py-6 text-lg rounded-2xl font-bold shadow-lg shadow-indigo-500/20"
              >
                Listed專頁
              </RippleButton>
            </Link>
          )}
          
          <Link to="/how-to-start">
            <RippleButton 
              variant="outline" 
              className="border-2 border-cyan-500 bg-cyan-50/50 backdrop-blur-sm text-cyan-700 hover:bg-cyan-100/30 px-8 py-6 text-lg rounded-2xl font-bold shadow-lg shadow-cyan-500/10"
            >
              如何開始
            </RippleButton>
          </Link>
          
          <Link to="/membership">
            <RippleButton className="bg-gradient-to-r from-cyan-600 to-teal-500 hover:from-cyan-700 hover:to-teal-600 text-white px-8 py-6 text-lg rounded-2xl shadow-lg shadow-cyan-600/20 font-bold">
              Join the Community
            </RippleButton>
          </Link>
          
          <Link to="/articles">
            <RippleButton 
              variant="outline" 
              className="border-2 border-cyan-500 bg-cyan-50/50 backdrop-blur-sm text-cyan-700 hover:bg-cyan-100/30 px-8 py-6 text-lg rounded-2xl font-bold shadow-lg shadow-cyan-500/10"
            >
              Read Articles
            </RippleButton>
          </Link>
        </div>
      </div>
    </section>
  );
};

export default Hero;
